package jalview.ws.slivkaws;

import jalview.gui.AlignFrame;
import jalview.ws.WSMenuEntryProviderI;
import jalview.ws.jws2.MsaWSClient;
import jalview.ws.jws2.SequenceAnnotationWSClient;

import java.io.IOError;
import java.io.IOException;
import java.net.URISyntaxException;

import javax.swing.JMenu;

import uk.ac.dundee.compbio.slivkaclient.SlivkaClient;
import uk.ac.dundee.compbio.slivkaclient.SlivkaService;

public class SlivkaWSDiscoverer implements Runnable, WSMenuEntryProviderI
{
  private static SlivkaWSDiscoverer instance = null;

  private SlivkaClient slivkaClient;

  private SlivkaWSDiscoverer()
  {
    try
    {
      slivkaClient = new SlivkaClient("gjb-www-1.cluster.lifesci.dundee.ac.uk", 3203);
    } catch (URISyntaxException e)
    {
      throw new RuntimeException(e);
    }
  }

  public static SlivkaWSDiscoverer getInstance()
  {
    if (instance == null)
    {
      instance = new SlivkaWSDiscoverer();
    }
    return instance;
  }

  @Override
  public void attachWSMenuEntry(JMenu wsmenu, final AlignFrame alignFrame)
  {
    JMenu slivkaMenu = new JMenu("Slivka");
    wsmenu.add(slivkaMenu);

    JMenu alignmentMenu = new JMenu("Sequence Alignment");
    slivkaMenu.add(alignmentMenu);
    try
    {
      for (SlivkaService service : slivkaClient.getServices())
      {
        msaClassifier:
        {
          for (String classifier : service.classifiers)
          {
            if (classifier.contains("Multiple sequence alignment"))
            {
              break msaClassifier;
            }
          }
          continue;
        }
        SlivkaMsaServiceInstance instance = new SlivkaMsaServiceInstance(slivkaClient, service);
        MsaWSClient client = new MsaWSClient();
        client.attachWSMenuEntry(alignmentMenu, instance, alignFrame);
        alignmentMenu.addSeparator();
      }
    } catch (IOException e)
    {
      // TODO Auto-generated catch block
      e.printStackTrace();
    }

    JMenu disorderMenu = new JMenu("Protein sequence analysis");
    slivkaMenu.add(disorderMenu);
    try
    {
      for (SlivkaService service : slivkaClient.getServices())
      {
        msaClassifier:
        {
          for (String classifier : service.classifiers)
          {
            if (classifier.contains("Protein sequence analysis"))
            {
              break msaClassifier;
            }
          }
          continue;
        }
        SlivkaAnnotationServiceInstance serviceInstance = new SlivkaAnnotationServiceInstance(slivkaClient, service);
        SequenceAnnotationWSClient client = new SequenceAnnotationWSClient();
        client.attachWSMenuEntry(disorderMenu, serviceInstance, alignFrame);
        disorderMenu.addSeparator();
      }
    } catch (IOException e)
    {
      throw new IOError(e);
    }
  }

  @Override
  public void run()
  {

  }
}
